import 'package:habo/habits/habit.dart';

abstract class HabitRepository {
  Future<List<Habit>> getAllHabits();
  Future<int> createHabit(Habit habit);
  Future<void> updateHabit(Habit habit);
  Future<void> deleteHabit(int id);
  Future<Habit?> findHabitById(int id);
  Future<void> updateHabitsOrder(List<Habit> habits);
  Future<void> deleteAllHabits();
  Future<void> insertHabits(List<Habit> habits);
}
